==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/DataVersion.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin

import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Any
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [DataVersion].
 */
@PulumiTagMarker
public class DataVersionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: DataVersionArgs = DataVersionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend DataVersionArgsBuilder.() -> Unit) {
        val builder = DataVersionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): DataVersion {
        val builtJavaResource =
            com.pulumi.azurenative.machinelearningservices.DataVersion(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return DataVersion(builtJavaResource)
    }
}

/**
 * Azure Resource Manager resource envelope.
 * Azure REST API version: 2023-04-01. Prior API version in Azure Native 1.x: 2021-03-01-preview.
 * Other available API versions: 2021-03-01-preview, 2022-02-01-preview, 2023-04-01-preview, 2023-06-01-preview, 2023-08-01-preview, 2023-10-01.
 * ## Example Usage
 * ### CreateOrUpdate Workspace Data Version Base.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var dataVersion = new AzureNative.MachineLearningServices.DataVersion("dataVersion", new()
 *     {
 *         DataVersionBaseProperties = new AzureNative.MachineLearningServices.Inputs.UriFileDataVersionArgs
 *         {
 *             DataType = "uri_file",
 *             DataUri = "string",
 *             Description = "string",
 *             IsAnonymous = false,
 *             Properties =
 *             {
 *                 { "string", "string" },
 *             },
 *             Tags =
 *             {
 *                 { "string", "string" },
 *             },
 *         },
 *         Name = "string",
 *         ResourceGroupName = "test-rg",
 *         Version = "string",
 *         WorkspaceName = "my-aml-workspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/machinelearningservices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := machinelearningservices.NewDataVersion(ctx, "dataVersion", &machinelearningservices.DataVersionArgs{
 * 			DataVersionBaseProperties: machinelearningservices.UriFileDataVersion{
 * 				DataType:    "uri_file",
 * 				DataUri:     "string",
 * 				Description: "string",
 * 				IsAnonymous: false,
 * 				Properties: map[string]interface{}{
 * 					"string": "string",
 * 				},
 * 				Tags: map[string]interface{}{
 * 					"string": "string",
 * 				},
 * 			},
 * 			Name:              pulumi.String("string"),
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 			Version:           pulumi.String("string"),
 * 			WorkspaceName:     pulumi.String("my-aml-workspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.machinelearningservices.DataVersion;
 * import com.pulumi.azurenative.machinelearningservices.DataVersionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var dataVersion = new DataVersion("dataVersion", DataVersionArgs.builder()
 *             .dataVersionBaseProperties(Map.ofEntries(
 *                 Map.entry("dataType", "uri_file"),
 *                 Map.entry("dataUri", "string"),
 *                 Map.entry("description", "string"),
 *                 Map.entry("isAnonymous", false),
 *                 Map.entry("properties", MLTableDataArgs.builder()
 *                     .string("string")
 *                     .build()),
 *                 Map.entry("tags", MLTableDataArgs.builder()
 *                     .string("string")
 *                     .build())
 *             ))
 *             .name("string")
 *             .resourceGroupName("test-rg")
 *             .version("string")
 *             .workspaceName("my-aml-workspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:machinelearningservices:DataVersion string /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MachineLearningServices/workspaces/{workspaceName}/data/{name}/versions/{version}
 * ```
 */
public class DataVersion internal constructor(
    override val javaResource: com.pulumi.azurenative.machinelearningservices.DataVersion,
) : KotlinCustomResource(javaResource, DataVersionMapper) {
    /**
     * [Required] Additional attributes of the entity.
     */
    public val dataVersionBaseProperties: Output<Any>
        get() = javaResource.dataVersionBaseProperties().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object DataVersionMapper : ResourceMapper<DataVersion> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.machinelearningservices.DataVersion::class == javaResource::class

    override fun map(javaResource: Resource): DataVersion = DataVersion(
        javaResource as
            com.pulumi.azurenative.machinelearningservices.DataVersion,
    )
}

/**
 * @see [DataVersion].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [DataVersion].
 */
public suspend fun dataVersion(name: String, block: suspend DataVersionResourceBuilder.() -> Unit):
    DataVersion {
    val builder = DataVersionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [DataVersion].
 * @param name The _unique_ name of the resulting resource.
 */
public fun dataVersion(name: String): DataVersion {
    val builder = DataVersionResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/DataVersion.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin

import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.machinelearningservices.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Any
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [DataVersion].
 */
@PulumiTagMarker
public class DataVersionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: DataVersionArgs = DataVersionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend DataVersionArgsBuilder.() -> Unit) {
        val builder = DataVersionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): DataVersion {
        val builtJavaResource =
            com.pulumi.azurenative.machinelearningservices.DataVersion(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return DataVersion(builtJavaResource)
    }
}

/**
 * Azure Resource Manager resource envelope.
 * Azure REST API version: 2023-04-01. Prior API version in Azure Native 1.x: 2021-03-01-preview.
 * Other available API versions: 2021-03-01-preview, 2022-02-01-preview, 2023-04-01-preview, 2023-06-01-preview, 2023-08-01-preview, 2023-10-01, 2024-01-01-preview.
 * ## Example Usage
 * ### CreateOrUpdate Workspace Data Version Base.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var dataVersion = new AzureNative.MachineLearningServices.DataVersion("dataVersion", new()
 *     {
 *         DataVersionBaseProperties = new AzureNative.MachineLearningServices.Inputs.UriFileDataVersionArgs
 *         {
 *             DataType = "uri_file",
 *             DataUri = "string",
 *             Description = "string",
 *             IsAnonymous = false,
 *             Properties =
 *             {
 *                 { "string", "string" },
 *             },
 *             Tags =
 *             {
 *                 { "string", "string" },
 *             },
 *         },
 *         Name = "string",
 *         ResourceGroupName = "test-rg",
 *         Version = "string",
 *         WorkspaceName = "my-aml-workspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/machinelearningservices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := machinelearningservices.NewDataVersion(ctx, "dataVersion", &machinelearningservices.DataVersionArgs{
 * 			DataVersionBaseProperties: machinelearningservices.UriFileDataVersion{
 * 				DataType:    "uri_file",
 * 				DataUri:     "string",
 * 				Description: "string",
 * 				IsAnonymous: false,
 * 				Properties: map[string]interface{}{
 * 					"string": "string",
 * 				},
 * 				Tags: map[string]interface{}{
 * 					"string": "string",
 * 				},
 * 			},
 * 			Name:              pulumi.String("string"),
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 			Version:           pulumi.String("string"),
 * 			WorkspaceName:     pulumi.String("my-aml-workspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.machinelearningservices.DataVersion;
 * import com.pulumi.azurenative.machinelearningservices.DataVersionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var dataVersion = new DataVersion("dataVersion", DataVersionArgs.builder()
 *             .dataVersionBaseProperties(Map.ofEntries(
 *                 Map.entry("dataType", "uri_file"),
 *                 Map.entry("dataUri", "string"),
 *                 Map.entry("description", "string"),
 *                 Map.entry("isAnonymous", false),
 *                 Map.entry("properties", MLTableDataArgs.builder()
 *                     .string("string")
 *                     .build()),
 *                 Map.entry("tags", MLTableDataArgs.builder()
 *                     .string("string")
 *                     .build())
 *             ))
 *             .name("string")
 *             .resourceGroupName("test-rg")
 *             .version("string")
 *             .workspaceName("my-aml-workspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:machinelearningservices:DataVersion string /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MachineLearningServices/workspaces/{workspaceName}/data/{name}/versions/{version}
 * ```
 */
public class DataVersion internal constructor(
    override val javaResource: com.pulumi.azurenative.machinelearningservices.DataVersion,
) : KotlinCustomResource(javaResource, DataVersionMapper) {
    /**
     * [Required] Additional attributes of the entity.
     */
    public val dataVersionBaseProperties: Output<Any>
        get() = javaResource.dataVersionBaseProperties().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object DataVersionMapper : ResourceMapper<DataVersion> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.machinelearningservices.DataVersion::class == javaResource::class

    override fun map(javaResource: Resource): DataVersion = DataVersion(
        javaResource as
            com.pulumi.azurenative.machinelearningservices.DataVersion,
    )
}

/**
 * @see [DataVersion].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [DataVersion].
 */
public suspend fun dataVersion(name: String, block: suspend DataVersionResourceBuilder.() -> Unit):
    DataVersion {
    val builder = DataVersionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [DataVersion].
 * @param name The _unique_ name of the resulting resource.
 */
public fun dataVersion(name: String): DataVersion {
    val builder = DataVersionResourceBuilder()
    builder.name(name)
    return builder.build()
}
